@@ -1416,7 +1416,7 @@ _split_list(ScoutWindow* self)
   GRegex * regexp;
   GMatchInfo* match_info;
   GError* error = NULL;
-  regexp = g_regex_new("((\\+|-)?(([^\"\\s]+\\b)|\"([^\"]+)\"))", 
+  regexp = g_regex_new("((\\+|-)?(([^\"\\s]+)|\"([^\"]+)\"))", 
 		       G_REGEX_OPTIMIZE, G_REGEX_MATCH_NOTEMPTY, &error);
   if(error)
   {
